<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bn">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>হঠাৎ</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 নতুন প্রবেশ প্রতীক</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 মিনিট আগে</translation>
    </message>
</context>
</TS>